@@ -22,27 +22,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <stdint.h>
 #include <pthread.h>
 
-// opened file list
-struct files_info
-{
-  pthread_mutex_t lock;
-  char        *name;
-  char        *real_name;
-  int         flags;
-  int         fh;
-  uint64_t    id;
-  struct files_info   *next, *prev;
-};
+#include "flist.h"
 
-extern struct files_info *files;
-
-void mhdd_tools_init(void);
-
-struct files_info * add_file_list(const char *name, 
-  const char *real_name, int flags, int fh);
-
-struct files_info * get_info_by_id(uint64_t id);
-void del_file_list(struct files_info * item);
 int get_free_dir(void);
 char * create_path(const char *dir, const char * file);
 char * find_path(const char *file);
@@ -52,15 +33,13 @@ int create_parent_dirs(int dir_id, const char *path);
 
 
 // true if success
-int move_file(struct files_info * file, off_t size);
+int move_file(struct flist * file, off_t size);
 
 
 // paths
 char * get_parent_path(const char * path);
 char * get_base_name(const char *path);
 
-void lock_files(void);
-void unlock_files(void);
 
 #define MOVE_BLOCK_SIZE     32768
 
